%* sasdrugdev_copy                                                                               *;
%*                                                                                               *;
%* Copies a file or folder to the specified target location.                                     *;
%*                                                                                               *;
%* The copy of a versioned file will not be versioned. The children of a copied folder will      *;
%* also be copied to the new location in their original directory structure.                     *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_COPY(SDD_SOURCE=sdd-source-path, SDD_TARGET=sdd-target-path);                     *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_source - required - the path of the object to be copied.                           *;
%* @param sdd_target - required - the path (including the new name) where the object is to be    *;
%*            copied. The target folder must already exist.                                      *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.1                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_copy(
  sdd_source=,
  sdd_target=
  ) /des='Copy a file or folder.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %*  Start the datastep to call the java code  *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RepositoryService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("copy", "%bquote(&sdd_source)", "%bquote(&sdd_target)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" The copy operation was successful.";
    end;
    else
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot successfully copy the object.  Target was not created." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put logMsgPrefix " sdd_source = &sdd_source" ;
    put logMsgPrefix " sdd_target = &sdd_target" ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_copy ;
