%* sasdrugdev_createuser                                                                         *;
%*                                                                                               *;
%* Creates a user account within the system.                                                     *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_CREATEUSER(SDD_USERID=sdd-userid, SDD_DISPLAYNAME=sdd-displayname,                *;
%* SDD_EMAIL=sdd-email, SDD_ACCOUNTTYPE=sdd-accounttype, SDD_PASSWORD=sdd-password,              *;
%* <, SDD_FIRSTNAME=sdd-firstname, SDD_LASTNAME=sdd-lastname, SDD_DEPARTMENT=sdd-department,     *;
%* SDD_PHONE=sdd-phone>);                                                                        *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_userid - required - the user ID of the account to create.                          *;
%* @param sdd_displayname - required - the display name of the account to create.                *;
%* @param sdd_email - required - the email address of the account to create.                     *;
%* @param sdd_accounttype - required - the account type of the account to create.                *;
%*            Values:  INTERACTIVE | NON_INTERACTIVE                                             *;
%*            Default: None                                                                      *;
%* @param sdd_password - required - the password for the account to create.                      *;
%* @param sdd_firstname - optional - the first name of the user associated with this account.    *;
%* @param sdd_lastname - optional - the last name of the user associated with this account.      *;
%* @param sdd_department - optional - the business unit of the user associated with this account.*;
%* @param sdd_phone - optional - the phone number of the user associated with this account.      *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-10-30 initial coding                                                            *;
%*                                                                                               *;

%macro sasdrugdev_createuser(
  sdd_userid=,
  sdd_displayname=,
  sdd_email=,
  sdd_accounttype=,
  sdd_password=,
  sdd_firstname=,
  sdd_lastname=,
  sdd_department=,
  sdd_phone=
  ) /des='Create a user account in the system.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/UserService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("create", "%bquote(&sdd_userid)", "%bquote(&sdd_displayname)", "%bquote(&sdd_email)",
                             "%bquote(&sdd_accounttype)", "%bquote(&sdd_password)", "%bquote(&sdd_firstname)",
                             "%bquote(&sdd_lastname)", "%bquote(&sdd_department)", "%bquote(&sdd_phone)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
    logMsg=" The user &sdd_userid was created." ;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot create user &sdd_userid." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_createuser;
