%* sasdrugdev_deleterole                                                                         *;
%*                                                                                               *;
%* Deletes a role from the specified organization, project, or analysis.                         *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_DELETEROLE(SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name);                            *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the role is defined.                                               *;
%* @param sdd_role - required - the name of the role to be deleted.                              *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_deleterole(
  sdd_path=,
  sdd_role=
  ) /des='Delete a role from the specified context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RoleService") ;
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("delete", "%bquote(&sdd_path)", "%bquote(&sdd_role)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
    logMsg=" * The role &sdd_role was deleted from &sdd_path.." ;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot delete role &sdd_role from &sdd_path.." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_deleterole ;
