%* sasdrugdev_removeroleprivilege                                                                *;
%*                                                                                               *;
%* Removes a privilege from a role in the specified organization, project, or analysis.          *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_REMOVEROLEPRIVILEGE(SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name,                    *;
%* SDD_PRIVILEGE=sdd-privilege-id);                                                              *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the role is defined.                                               *;
%* @param sdd_role - required - the name of the role that the privilege is to be removed from.   *;
%* @param sdd_privilege - required - the identifier of the privilege to remove.                  *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_removeroleprivilege(
  sdd_path=,
  sdd_role=,
  sdd_privilege=
  ) /des='Remove a privilege from a role in the specified context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RoleService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("removePrivilege", "%bquote(&sdd_path)", "%bquote(&sdd_role)", "%bquote(&sdd_privilege)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" The privilege &sdd_privilege has been removed from &sdd_role in &sdd_path.." ;
    end;
      else
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot remove privilege &sdd_privilege from &sdd_role in &sdd_path.." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_removeroleprivilege;
