%* sasdrugdev_removeuserprivilege                                                                *;
%*                                                                                               *;
%* Remove a global privilege from a user in the system.                                          *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ROLEEXISTS(SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name);                            *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_userid - required - the user to remove the global privilege from.                  *;
%* @param sdd_privilege - required - the identifier of the global privilege to remove.           *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-11-01 initial coding                                                            *;
%*                                                                                               *;

%macro sasdrugdev_removeuserprivilege(
  sdd_userid=,
  sdd_privilege=
  ) /des='Remove a global privilege from a user.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/PrivilegeService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("removePrivilege", "%bquote(&sdd_userid)", "%bquote(&sdd_privilege)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" The global privilege &sdd_privilege has been removed from the user &sdd_userid.." ;
    end;
      else
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot remove the global privilege &sdd_privilege from the user &sdd_userid.." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_removeuserprivilege;
