%* sasdrugdev_renameproject                                                                      *;
%*                                                                                               *;
%* Renames a project.                                                                            *;
%*                                                                                               *;
%* Another project with the new name must not already exist in the organization.                 *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_RENAMEPROJECT(SDD_SOURCE=sdd-source-path, SDD_NEWNAME=sdd-new-name);              *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_source   - required - the path, including the name, of the project to be renamed.  *;
%* @param sdd_newname  - required - the new name of the project.                                 *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2014-03-04  initial coding                                                           *;
%*                                                                                               *;

%macro sasdrugdev_renameproject(
  sdd_source=,
  sdd_newname=
  ) /des='Rename a project.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %*  Start the datastep to call the java code  *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/ProjectService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("rename", "%bquote(&sdd_source)", "%bquote(&sdd_newname)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" The project rename operation was successful.";
    end;
    else
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot successfully rename the project.  The project was not renamed." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put logMsgPrefix " sdd_source = &sdd_source" ;
    put logMsgPrefix " sdd_newname = &sdd_newname" ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_renameproject;
