%* sasdrugdev_updateuserinfo                                                                     *;
%*                                                                                               *;
%* Update general user account information                                                       *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_UPDATEUSERINFO(SDD_USERID=sdd-userid, < SDD_DISPLAYNAME=sdd-displayname,          *;
%* SDD_EMAIL=sdd-email, SDD_ACCOUNTTYPE=sdd-accounttype, SDD_FIRSTNAME=sdd-firstname,            *;
%* SDD_LASTNAME=sdd-lastname, SDD_DEPARTMENT=sdd-department, SDD_PHONE=sdd-phone >);             *;
%*                                                                                               *;
%* You must have either the Manage User Account General Information or the Manage Users global   *;
%* privilege in order to update user information.                                                *;
%*                                                                                               *;
%* If an optional parameter is not passed in, no change to the existing user attribute value     *;
%* will be made.  If the parameter is pased in, the specified value will be set on the user      *;
%* attribute. Parameter values must conform to SDD validation rules.                             *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_userid - required - the user ID of the account being updated.                      *;
%* @param sdd_displayname - optional - the user display name to be set.                          *;
%* @param sdd_email - optional - the user email address.                                         *;
%* @param sdd_accounttype - optional - the user account type.                                    *;
%*            Values:  INTERACTIVE | NON_INTERACTIVE                                             *;
%* @param sdd_firstname - optional - the user first name.                                        *;
%* @param sdd_lastname - optional - the last name of the user.                                   *;
%* @param sdd_department - optional - the business unit of the user.                             *;
%* @param sdd_phone - optional - the phone number of the user.                                   *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2014-03-27 initial coding                                                            *;
%*                                                                                               *;

%macro sasdrugdev_updateuserinfo(
  sdd_userid=,
  sdd_displayname=_sdd_updateuser_donotupdate_,
  sdd_email=_sdd_updateuser_donotupdate_,
  sdd_accounttype=_sdd_updateuser_donotupdate_,
  sdd_firstname=_sdd_updateuser_donotupdate_,
  sdd_lastname=_sdd_updateuser_donotupdate_,
  sdd_department=_sdd_updateuser_donotupdate_,
  sdd_phone=_sdd_updateuser_donotupdate_
  ) /des='Update a user account in the system.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/UserService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("update", "%bquote(&sdd_userid)", "%bquote(&sdd_displayname)", "%bquote(&sdd_email)",
                             "%bquote(&sdd_accounttype)", "%bquote(&sdd_firstname)", "%bquote(&sdd_lastname)",
                             "%bquote(&sdd_department)", "%bquote(&sdd_phone)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
    logMsg=" The user account &sdd_userid was updated." ;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot update user account &sdd_userid." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_updateuserinfo;
